*earn_tab_20_ties.do
capture log close
log using "U:\papers and projects\earnings associations\filecreation\earn_tab_20_ties.log", replace
set more 1
clear
program drop _all
set mem 600M


************
* THIS FILE TURNS THE COUPLE-LEVEL DATA SET INTO A TABULAR DATA SET FOR
* RUNNING THE LOG-LINEAR MODELS
********


  use "U:\papers and projects\earnings associations\dta\topcode.dta", clear

#delimit cr


     ***This part deflates the weights so that the original
     ***sample size is maintained


        bysort y: egen double sumwgt = sum(WEIGHT)
        bysort y: gen N = _N


        bysort y: gen double deflate = N/sumwgt



        *preserve original weight variables
         rename WEIGHT oweight

        bysort y: gen double WEIGHT = oweight*deflate



keep WEIGHT y W H





    *******************************************************
    ***CALCULATE PERCENTILES FOR THOSE WHO HAVE WAGES   ***
    *******************************************************


      preserve

       #delimit ;

       collapse (p3)  p3W=W
                (p5)  p5W=W
                (p8)  p8W=W
                (p10) p10W=W
                (p13) p13W=W
                (p15) p15W=W
                (p18) p18W=W
                (p20) p20W=W
                (p23) p23W=W
                (p25) p25W=W
                (p28) p28W=W
                (p30) p30W=W
                (p33) p33W=W
                (p35) p35W=W
                (p38) p38W=W
                (p40) p40W=W
                (p43) p43W=W
                (p45) p45W=W
                (p48) p48W=W
                (p50) p50W=W
                (p53) p53W=W
                (p55) p55W=W
                (p58) p58W=W
                (p60) p60W=W
                (p63) p63W=W
                (p65) p65W=W
                (p68) p68W=W
                (p70) p70W=W
                (p73) p73W=W
                (p75) p75W=W
                (p78) p78W=W
                (p80) p80W=W
                (p83) p83W=W
                (p85) p85W=W
                (p88) p88W=W
                (p90) p90W=W
                (p93) p93W=W
                (p95) p95W=W
                (p98) p98W=W [w=WEIGHT] if W > 0, by(y) ;

       #delimit cr


       sort y


       tempfile wps
       save `wps'

      restore


      preserve

       #delimit ;

       collapse (p3)  p3H=H
                (p5)  p5H=H
                (p8)  p8H=H
                (p10) p10H=H
                (p13) p13H=H
                (p15) p15H=H
                (p18) p18H=H
                (p20) p20H=H
                (p23) p23H=H
                (p25) p25H=H
                (p28) p28H=H
                (p30) p30H=H
                (p33) p33H=H
                (p35) p35H=H
                (p38) p38H=H
                (p40) p40H=H
                (p43) p43H=H
                (p45) p45H=H
                (p48) p48H=H
                (p50) p50H=H
                (p53) p53H=H
                (p55) p55H=H
                (p58) p58H=H
                (p60) p60H=H
                (p63) p63H=H
                (p65) p65H=H
                (p68) p68H=H
                (p70) p70H=H
                (p73) p73H=H
                (p75) p75H=H
                (p78) p78H=H
                (p80) p80H=H
                (p83) p83H=H
                (p85) p85H=H
                (p88) p88H=H
                (p90) p90H=H
                (p93) p93H=H
                (p95) p95H=H
                (p98) p98H=H [w=WEIGHT] if H > 0, by(y) ;

       #delimit cr


       sort y


       tempfile hps
       save `hps'

      restore


      ****************
      **Tie breakers**
      ****************


       *Create a random tie breaker. This allocates people who are exactly on the border
       *of a percentile category to one category or the other at random. Doing so keeps
       *the distribution uniform.

        set seed 100
        gen breaker = uniform()

         *****************
         **-- Wives   --**
         *****************

       sort y W breaker
       by y: gen nW = _n

      preserve

       #delimit ;

       collapse (p5)  p5nW=nW
                (p10) p10nW=nW
                (p15) p15nW=nW
                (p20) p20nW=nW
                (p25) p25nW=nW
                (p30) p30nW=nW
                (p35) p35nW=nW
                (p40) p40nW=nW
                (p45) p45nW=nW
                (p50) p50nW=nW
                (p55) p55nW=nW
                (p60) p60nW=nW
                (p65) p65nW=nW
                (p70) p70nW=nW
                (p75) p75nW=nW
                (p80) p80nW=nW
                (p85) p85nW=nW
                (p90) p90nW=nW
                (p95) p95nW=nW
                [w=WEIGHT] if W > 0, by(y) ;

       #delimit cr


       sort y


       tempfile wps_n
       save `wps_n'

      restore


         *****************
         **-- Husbands--**
         *****************



       sort y H breaker
       by y: gen nH = _n

      preserve

       #delimit ;

       collapse (p5)  p5nH=nH
                (p10) p10nH=nH
                (p15) p15nH=nH
                (p20) p20nH=nH
                (p25) p25nH=nH
                (p30) p30nH=nH
                (p35) p35nH=nH
                (p40) p40nH=nH
                (p45) p45nH=nH
                (p50) p50nH=nH
                (p55) p55nH=nH
                (p60) p60nH=nH
                (p65) p65nH=nH
                (p70) p70nH=nH
                (p75) p75nH=nH
                (p80) p80nH=nH
                (p85) p85nH=nH
                (p90) p90nH=nH
                (p95) p95nH=nH
                [w=WEIGHT] if H > 0, by(y) ;

       #delimit cr


       sort y


       tempfile hps_n
       save `hps_n'

      restore

      **merge percentiles onto individual-level file

      sort y
      merge y using `wps'
      drop _merge

      sort y
      merge y using `hps'
      drop _merge

      sort y
      merge y using `wps_n'
      drop _merge

      sort y
      merge y using `hps_n'
      drop _merge



      **Assign everyone to a percentile category.


       foreach pre in W H {
          quietly gen     `pre'p = 0   if `pre' == 0
          quietly replace `pre'p = 5  if `pre'  > 0 & n`pre' <= p5n`pre'
          quietly replace `pre'p = 100 if n`pre'  > p95n`pre'
           forvalues j = 10(5)95 {
            local k = `j' - 5
             quietly replace `pre'p = `j' if n`pre' > p`k'n`pre' & n`pre' <= p`j'n`pre'
           }
       }

     **Assign scale scores to percentile categories.  For those in percentiles 1-5, assign earnings at the 3rd percentile,
     **For those in percentiles 6-10, assign earnings at the 8th percentil and so forth.

      foreach pre in W H {
       quietly gen `pre'scale = 0 if `pre'p == 0
         forvalues i = 5(5)100 {
          local j = `i' - 2
           quietly replace `pre'scale = p`j'`pre' if `pre'p == `i'
       }
      }



    ***********************************
    ***Create the data table        ***
    ***********************************


    gen freq = 1

    collapse (sum) freq WEIGHT (mean) Wscale Hscale, by(y Wp Hp)


  #delimit ;

   ******************
   * WEIGHTING CODE *
   ****************** ;


   ***To weight the data, follow Agresti page 391 section 9.7.5.

      zi = the total weighted frequency divided by the cell
      count.  In my case, this is:

      WEIGHT/freq = zi

      Loglinear models for the weighted expected frequencies
      (zi*mui = mui/ti) with ti = 1/zi expresses the model as
      a standard loglinear model for logmui with offset
      (logti = -logzi).

      What this means is the offset is equal to:

      -ln(zi)

      crs 2/25/04 ;


   #delimit cr


   gen zi      = (WEIGHT/freq)
   gen neglnzi = -ln(zi)


  *Deal with zero cells
   replace neglnzi = 0 if neglnzi == .


 quietly compress

 save "U:\papers and projects\earnings associations\dta\earn_tab_20_ties.dta", replace

 tab y
 tab y [w=freq]


